==> cdcam-1.0.0rc1.tar.gz: cdcam-1.0.0rc1/tests/test_mobile_interventions.py <==
"""
Test interventions.py

11th May 2019
Written by Ed Oughton

"""
import pytest
from cdcam.interventions import decide_interventions, _area_satisfied
from cdcam.model import NetworkManager, PostcodeSector

@pytest.fixture
def basic_system(setup_lad, setup_pcd_sector, setup_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector,
        setup_assets, setup_capacity_lookup, setup_clutter_lookup,
        setup_simulation_parameters)

    return system


@pytest.fixture
def non_4g_system(setup_lad, setup_pcd_sector, setup_non_4g_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector,
        setup_non_4g_assets, setup_capacity_lookup,
        setup_clutter_lookup, setup_simulation_parameters)

    return system


@pytest.fixture
def mixed_system(setup_lad, setup_pcd_sector, setup_mixed_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector, setup_mixed_assets,
        setup_capacity_lookup, setup_clutter_lookup,
        setup_simulation_parameters)

    return system


def test_decide_interventions(non_4g_system, basic_system,
    mixed_system, setup_simulation_parameters):

    actual_result = decide_interventions(
        'minimal', 250000, 0,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert actual_result == ([], 250000, [])

    actual_result = decide_interventions(
        'upgrade_to_lte', 142446, 2,
        non_4g_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 2
    assert actual_result[1] == 0

    actual_result = decide_interventions(
        'upgrade_to_lte', 142446, 2,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert actual_result == ([], 142446, [])

    # #50917 * 4 = 203668
    actual_result = decide_interventions(
        'macrocell', 203668, 10,
        mixed_system, 2020, setup_simulation_parameters
    )
    assert len(actual_result[0]) == 4
    assert actual_result[1] == 0

    actual_result = decide_interventions(
        'macrocell', 203668, 0,
        mixed_system, 2020, setup_simulation_parameters
    )
    assert len(actual_result[0]) == 0
    assert actual_result[1] == 203668

    # actual_result = decide_interventions(
    #     'macrocell_700', 50917, 10,
    #     mixed_system, 2020, setup_simulation_parameters
    # )

    # assert len(actual_result[0]) == 1
    # assert actual_result[1] == 0

    # #50917 * 2 = 101,834
    # #40220 * 3 = £120,660
    actual_result = decide_interventions(
        'small-cell-and-spectrum', 203668 , 1000,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 4
    assert actual_result[1] == 0

==> cdcam-1.0.1.tar.gz: cdcam-1.0.1/tests/test_mobile_interventions.py <==
"""
Test interventions.py

11th May 2019
Written by Ed Oughton

"""
import pytest
from cdcam.interventions import decide_interventions, _area_satisfied
from cdcam.model import NetworkManager, PostcodeSector

@pytest.fixture
def basic_system(setup_lad, setup_pcd_sector, setup_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector,
        setup_assets, setup_capacity_lookup, setup_clutter_lookup,
        setup_simulation_parameters)

    return system


@pytest.fixture
def non_4g_system(setup_lad, setup_pcd_sector, setup_non_4g_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector,
        setup_non_4g_assets, setup_capacity_lookup,
        setup_clutter_lookup, setup_simulation_parameters)

    return system


@pytest.fixture
def mixed_system(setup_lad, setup_pcd_sector, setup_mixed_assets,
    setup_capacity_lookup, setup_clutter_lookup,
    setup_simulation_parameters):

    system = NetworkManager(setup_lad, setup_pcd_sector, setup_mixed_assets,
        setup_capacity_lookup, setup_clutter_lookup,
        setup_simulation_parameters)

    return system


@pytest.fixture
def empty_system(setup_lad, setup_pcd_sectors2, setup_non_4g_assets,
    setup_capacity_lookup_table2, setup_clutter_lookup,
    setup_simulation_parameters2):

    system = NetworkManager(setup_lad, setup_pcd_sectors2,
        setup_non_4g_assets, setup_capacity_lookup_table2, setup_clutter_lookup,
        setup_simulation_parameters2)

    return system


@pytest.fixture
def high_demand_system(setup_lad, setup_pcd_sectors2, setup_assets,
    setup_capacity_lookup_table2, setup_clutter_lookup,
    setup_simulation_parameters2):

    system = NetworkManager(setup_lad, setup_pcd_sectors2,
        setup_assets, setup_capacity_lookup_table2, setup_clutter_lookup,
        setup_simulation_parameters2)

    return system


def test_decide_interventions(non_4g_system, basic_system,
    mixed_system, empty_system, high_demand_system, setup_simulation_parameters,
    setup_simulation_parameters2):

    actual_result = decide_interventions(
        'minimal', 250000, 0,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert actual_result == ([], 250000, [])

    actual_result = decide_interventions(
        'upgrade_to_lte', 142446, 2,
        non_4g_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 2
    assert actual_result[1] == 0

    actual_result = decide_interventions(
        'upgrade_to_lte', 142446, 2,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert actual_result == ([], 142446, [])

    # #50917 * 4 = 203668
    actual_result = decide_interventions(
        'macrocell', 109000, 1000,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 4
    assert actual_result[1] == 0

    actual_result = decide_interventions(
        'macrocell', 203668, 0,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 0
    assert actual_result[1] == 203668

    # #50917 * 2 = 101,834
    # #40220 * 3 = £120,660
    actual_result = decide_interventions(
        'small-cell-and-spectrum', 109000 , 1000,
        mixed_system, 2020, setup_simulation_parameters
    )

    assert len(actual_result[0]) == 4
    assert actual_result[1] == 0

    #test empty_system
    actual_result = decide_interventions(
        'small-cell-and-spectrum', 1e7 , 0,
        empty_system, 2020, setup_simulation_parameters2
    )

    macros_to_lte = len([a for a in actual_result[0] if  a['type'] == 'macrocell_site' \
                    and a['technology'] == 'LTE'])

    assert macros_to_lte == 4

    #test high_demand_system
    actual_result = decide_interventions(
        'small-cell-and-spectrum', 1e7 , 0,
        high_demand_system, 2020, setup_simulation_parameters2
    )

    macros_to_5g = len([a for a in actual_result[0] if  a['type'] == 'macrocell_site' \
                    and a['technology'] == '5G'])

    assert macros_to_5g == 6

    #test small cell build
    actual_result = decide_interventions(
        'small-cell-and-spectrum', 1e6 , 0,
        high_demand_system, 2020, setup_simulation_parameters2
    )

    small_cells = len([a for a in actual_result[0] if  a['type'] == 'small_cell'])

    assert small_cells == 2
